from typing import Annotated
from contextlib import asynccontextmanager
import logging

from fastapi import FastAPI, Depends, BackgroundTasks, HTTPException, status
from fastapi.responses import FileResponse, HTMLResponse
from hatchet_sdk import EmptyModel
from jwt import decode as decode_jwt

from knoc.settings import settings
from knoc.workflows.foo import foo_wf, SimpleOutput
from knoc.workflows.utils import ImportReport

logger = logging.getLogger("knoc")


@asynccontextmanager
async def lifespan(app: FastAPI):
    # Load the FastAPI app
    logger.debug("App is Starting Up!")
    yield
    logger.info(
        "App is Shutting Down Gracefully!",
        extra={"markup": True},
    )


app = FastAPI(lifespan=lifespan)


@app.get("/")
async def root():
    hatchet_console_url = decode_jwt(
        settings.hatchet_client.token, options={"verify_signature": False}
    )["server_url"]
    return HTMLResponse(
        f'<a href="{hatchet_console_url}">Hatchet console</a>'
        "<hr>"
        '<a href="/process/foo_task">foo task (for testing)</a>'
    )


@app.get("/process/foo_task")
async def process_foo_task() -> dict[str, SimpleOutput]:
    result = await foo_wf.aio_run(EmptyModel())
    return result
