#!/usr/bin/env python
"""Knoc worker for Hatchet.
It reads its config from environment variables, a, .env file or yaml file,
connects to the Hatcher server using the JWT token in the config,
and executes the tasks and workflows orders.
"""

import sys
import logging
import typer
from typing import Annotated

logger = logging.getLogger("knoc-worker")

app = typer.Typer(no_args_is_help=True)


@app.command()
def run(
    name: str = "knoc-worker",
    label: Annotated[
        list[str],
        typer.Option(
            help="Add a key:value label to the client (can be used multiple times)"
        ),
    ] = [],
) -> None:
    """Run a worker"""
    labels = {}
    for label_ in label:
        try:
            key, value = label_.split(":", 1)
            labels[key] = value
        except ValueError:
            logger.error("Labels must be in key:value format")
            sys.exit(1)

    from knoc.hatchet_client import hatchet
    from knoc.workflows import all_wfs

    worker = hatchet.worker(
        name=name,
        workflows=all_wfs,
        labels=labels,
    )
    worker.start()


if __name__ == "__main__":
    app()
